@@ -114,7 +114,7 @@ window.GoAccess = window.GoAccess || {
 			if (wsConn.ping_interval)
 				pingId = setInterval(() => { socket.send('ping'); }, wsConn.ping_interval * 1E3);
 
-			GoAccess.Nav.WSOpen();
+			GoAccess.Nav.WSOpen(str);
 		}.bind(this);
 
 		socket.onmessage = function (event) {
@@ -245,7 +245,7 @@ GoAccess.Util = {
 			val = value;
 		}
 
-		return value == 0 ? String(val) : val;
+		return value == 0 ? String(val) : (val === undefined ? '—' : val);
 	},
 
 	isPanelHidden: function (panel) {
@@ -671,10 +671,10 @@ GoAccess.Nav = {
 		});
 	},
 
-	WSOpen: function () {
+	WSOpen: function (str) {
 		$$('.nav-ws-status', function (item) {
 			item.classList.add('connected');
-			item.setAttribute('title', 'Connected to ' + GoAccess.AppWSConn.url);
+			item.setAttribute('title', 'Connected to ' + str);
 		});
 	},
 
